<?php

namespace Drupal\registration_link\Access;

use Drupal\user\UserInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access check for user registration routes.
 *
 * @package Drupal\registration_link\Access
 */
class RegistrationLinkAccessCheck implements AccessInterface {

  /**
   * Checks access.
   *
   * @param AccountInterface $account
   *   The currently logged in account.
   *
   * @return $this|\Drupal\Core\Access\AccessResultAllowed
   *   The access result.
   */
  public function access(AccountInterface $account) {
    $user_settings = \Drupal::config('user.settings');
    if (in_array('administrator', $account->getRoles())) {
      return AccessResult::allowed();
    }

    return AccessResult::allowedIf(
      $account->isAnonymous()
      && $user_settings->get('register') != UserInterface::REGISTER_ADMINISTRATORS_ONLY)
      ->addCacheableDependency($user_settings);
  }

}
